@@ -1,13 +1,11 @@
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 import collections
 import logging
 import time
 
 from mopidy import exceptions
-from mopidy.audio import tags as tags_lib, utils
-from mopidy.internal import encoding, log
+from mopidy.audio import tags as tags_lib
+from mopidy.audio import utils
+from mopidy.internal import log
 from mopidy.internal.gi import Gst, GstPbutils
 
 # GST_ELEMENT_FACTORY_LIST:
@@ -22,7 +20,8 @@ _SELECT_TRY = 0
 _SELECT_EXPOSE = 1
 
 _Result = collections.namedtuple(
-    'Result', ('uri', 'tags', 'duration', 'seekable', 'mime', 'playable'))
+    "Result", ("uri", "tags", "duration", "seekable", "mime", "playable")
+)
 
 logger = logging.getLogger(__name__)
 
@@ -32,7 +31,7 @@ def _trace(*args, **kwargs):
 
 
 # TODO: replace with a scan(uri, timeout=1000, proxy_config=None)?
-class Scanner(object):
+class Scanner:
 
     """
     Helper to get tags and other relevant info from URIs.
@@ -83,21 +82,21 @@ class Scanner(object):
 def _setup_pipeline(uri, proxy_config=None):
     src = Gst.Element.make_from_uri(Gst.URIType.SRC, uri)
     if not src:
-        raise exceptions.ScannerError('GStreamer can not open: %s' % uri)
+        raise exceptions.ScannerError(f"GStreamer can not open: {uri}")
 
     if proxy_config:
         utils.setup_proxy(src, proxy_config)
 
     signals = utils.Signals()
-    pipeline = Gst.ElementFactory.make('pipeline')
+    pipeline = Gst.ElementFactory.make("pipeline")
     pipeline.add(src)
 
     if _has_src_pads(src):
-        _setup_decodebin(src, src.get_static_pad('src'), pipeline, signals)
+        _setup_decodebin(src, src.get_static_pad("src"), pipeline, signals)
     elif _has_dynamic_src_pad(src):
-        signals.connect(src, 'pad-added', _setup_decodebin, pipeline, signals)
+        signals.connect(src, "pad-added", _setup_decodebin, pipeline, signals)
     else:
-        raise exceptions.ScannerError('No pads found in source element.')
+        raise exceptions.ScannerError("No pads found in source element.")
 
     return pipeline, signals
 
@@ -117,46 +116,46 @@ def _has_dynamic_src_pad(element):
 
 
 def _setup_decodebin(element, pad, pipeline, signals):
-    typefind = Gst.ElementFactory.make('typefind')
-    decodebin = Gst.ElementFactory.make('decodebin')
+    typefind = Gst.ElementFactory.make("typefind")
+    decodebin = Gst.ElementFactory.make("decodebin")
 
     for element in (typefind, decodebin):
         pipeline.add(element)
         element.sync_state_with_parent()
 
-    pad.link(typefind.get_static_pad('sink'))
+    pad.link(typefind.get_static_pad("sink"))
     typefind.link(decodebin)
 
-    signals.connect(typefind, 'have-type', _have_type, decodebin)
-    signals.connect(decodebin, 'pad-added', _pad_added, pipeline)
-    signals.connect(decodebin, 'autoplug-select', _autoplug_select)
+    signals.connect(typefind, "have-type", _have_type, decodebin)
+    signals.connect(decodebin, "pad-added", _pad_added, pipeline)
+    signals.connect(decodebin, "autoplug-select", _autoplug_select)
 
 
 def _have_type(element, probability, caps, decodebin):
-    decodebin.set_property('sink-caps', caps)
-    struct = Gst.Structure.new_empty('have-type')
-    struct.set_value('caps', caps.get_structure(0))
+    decodebin.set_property("sink-caps", caps)
+    struct = Gst.Structure.new_empty("have-type")
+    struct.set_value("caps", caps.get_structure(0))
     element.get_bus().post(Gst.Message.new_application(element, struct))
 
 
 def _pad_added(element, pad, pipeline):
-    sink = Gst.ElementFactory.make('fakesink')
-    sink.set_property('sync', False)
+    sink = Gst.ElementFactory.make("fakesink")
+    sink.set_property("sync", False)
 
     pipeline.add(sink)
     sink.sync_state_with_parent()
-    pad.link(sink.get_static_pad('sink'))
+    pad.link(sink.get_static_pad("sink"))
 
-    if pad.query_caps().is_subset(Gst.Caps.from_string('audio/x-raw')):
+    if pad.query_caps().is_subset(Gst.Caps.from_string("audio/x-raw")):
         # Probably won't happen due to autoplug-select fix, but lets play it
         # safe until we've tested more.
-        struct = Gst.Structure.new_empty('have-audio')
+        struct = Gst.Structure.new_empty("have-audio")
         element.get_bus().post(Gst.Message.new_application(element, struct))
 
 
 def _autoplug_select(element, pad, caps, factory):
     if factory.list_is_type(_DECODER | _AUDIO):
-        struct = Gst.Structure.new_empty('have-audio')
+        struct = Gst.Structure.new_empty("have-audio")
         element.get_bus().post(Gst.Message.new_application(element, struct))
     if not factory.list_is_type(_DEMUXER | _DEPAYLOADER | _PARSER):
         return _SELECT_EXPOSE
@@ -195,13 +194,13 @@ def _process(pipeline, timeout_ms):
     duration = None
 
     types = (
-        Gst.MessageType.ELEMENT |
-        Gst.MessageType.APPLICATION |
-        Gst.MessageType.ERROR |
-        Gst.MessageType.EOS |
-        Gst.MessageType.ASYNC_DONE |
-        Gst.MessageType.DURATION_CHANGED |
-        Gst.MessageType.TAG
+        Gst.MessageType.ELEMENT
+        | Gst.MessageType.APPLICATION
+        | Gst.MessageType.ERROR
+        | Gst.MessageType.EOS
+        | Gst.MessageType.ASYNC_DONE
+        | Gst.MessageType.DURATION_CHANGED
+        | Gst.MessageType.TAG
     )
 
     timeout = timeout_ms
@@ -214,27 +213,28 @@ def _process(pipeline, timeout_ms):
         if logger.isEnabledFor(log.TRACE_LOG_LEVEL) and msg.get_structure():
             debug_text = msg.get_structure().to_string()
             if len(debug_text) > 77:
-                debug_text = debug_text[:77] + '...'
-            _trace('element %s: %s', msg.src.get_name(), debug_text)
+                debug_text = debug_text[:77] + "..."
+            _trace("element %s: %s", msg.src.get_name(), debug_text)
 
         if msg.type == Gst.MessageType.ELEMENT:
             if GstPbutils.is_missing_plugin_message(msg):
                 missing_message = msg
         elif msg.type == Gst.MessageType.APPLICATION:
-            if msg.get_structure().get_name() == 'have-type':
-                mime = msg.get_structure().get_value('caps').get_name()
+            if msg.get_structure().get_name() == "have-type":
+                mime = msg.get_structure().get_value("caps").get_name()
                 if mime and (
-                        mime.startswith('text/') or mime == 'application/xml'):
+                    mime.startswith("text/") or mime == "application/xml"
+                ):
                     return tags, mime, have_audio, duration
-            elif msg.get_structure().get_name() == 'have-audio':
+            elif msg.get_structure().get_name() == "have-audio":
                 have_audio = True
         elif msg.type == Gst.MessageType.ERROR:
-            error = encoding.locale_decode(msg.parse_error()[0])
+            error, _debug = msg.parse_error()
             if missing_message and not mime:
-                caps = missing_message.get_structure().get_value('detail')
+                caps = missing_message.get_structure().get_value("detail")
                 mime = caps.get_structure(0).get_name()
                 return tags, mime, have_audio, duration
-            raise exceptions.ScannerError(error)
+            raise exceptions.ScannerError(str(error))
         elif msg.type == Gst.MessageType.EOS:
             return tags, mime, have_audio, duration
         elif msg.type == Gst.MessageType.ASYNC_DONE:
@@ -250,7 +250,7 @@ def _process(pipeline, timeout_ms):
             # after pre-roll. We get around this by starting to play the track
             # and then waiting for a duration change.
             # https://bugzilla.gnome.org/show_bug.cgi?id=763553
-            logger.debug('Using workaround for duration missing before play.')
+            logger.debug("Using workaround for duration missing before play.")
             result = pipeline.set_state(Gst.State.PLAYING)
             if result == Gst.StateChangeReturn.FAILURE:
                 return tags, mime, have_audio, duration
@@ -269,17 +269,19 @@ def _process(pipeline, timeout_ms):
 
         timeout = timeout_ms - (int(time.time() * 1000) - start)
 
-    raise exceptions.ScannerError('Timeout after %dms' % timeout_ms)
+    raise exceptions.ScannerError(f"Timeout after {timeout_ms:d}ms")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import os
     import sys
 
     from mopidy.internal import path
 
-    logging.basicConfig(format='%(asctime)-15s %(levelname)s %(message)s',
-                        level=log.TRACE_LOG_LEVEL)
+    logging.basicConfig(
+        format="%(asctime)-15s %(levelname)s %(message)s",
+        level=log.TRACE_LOG_LEVEL,
+    )
 
     scanner = Scanner(5000)
     for uri in sys.argv[1:]:
@@ -287,13 +289,14 @@ if __name__ == '__main__':
             uri = path.path_to_uri(os.path.abspath(uri))
         try:
             result = scanner.scan(uri)
-            for key in ('uri', 'mime', 'duration', 'playable', 'seekable'):
-                print('%-20s   %s' % (key, getattr(result, key)))
-            print('tags')
+            for key in ("uri", "mime", "duration", "playable", "seekable"):
+                value = getattr(result, key)
+                print(f"{key:<20}   {value}")
+            print("tags")
             for tag, value in result.tags.items():
-                line = '%-20s   %s' % (tag, value)
+                line = f"{tag:<20}   {value}"
                 if len(line) > 77:
-                    line = line[:77] + '...'
+                    line = line[:77] + "..."
                 print(line)
         except exceptions.ScannerError as error:
-            print('%s: %s' % (uri, error))
+            print(f"{uri}: {error}")
