@@ -149,7 +149,7 @@ class TestPlayHandling(BaseTest):
 
     def test_resume_skips_to_next_on_unplayable_track(self):
         """Checks that we handle backend.change_track failing when
-           resuming playback."""
+        resuming playback."""
         tl_tracks = self.core.tracklist.get_tl_tracks()
 
         self.core.playback.play(tl_tracks[0])
@@ -176,6 +176,11 @@ class TestPlayHandling(BaseTest):
     def test_default_is_live_behaviour_is_not_live(self):
         assert not self.backend.playback.is_live(self.tracks[0].uri).get()
 
+    def test_download_buffering_is_not_enabled_by_default(self):
+        assert not self.backend.playback.should_download(
+            self.tracks[0].uri
+        ).get()
+
 
 class TestNextHandling(BaseTest):
     def test_get_current_tl_track_next(self):
