@@ -4,7 +4,6 @@ This backend implements the backend API in the simplest way possible.  It is
 used in tests of the frontends.
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import pykka
 
@@ -17,9 +16,8 @@ def create_proxy(config=None, audio=None):
 
 
 class DummyBackend(pykka.ThreadingActor, backend.Backend):
-
     def __init__(self, config, audio):
-        super(DummyBackend, self).__init__()
+        super().__init__()
 
         self.library = DummyLibraryProvider(backend=self)
         if audio:
@@ -28,14 +26,14 @@ class DummyBackend(pykka.ThreadingActor, backend.Backend):
             self.playback = DummyPlaybackProvider(audio=audio, backend=self)
         self.playlists = DummyPlaylistsProvider(backend=self)
 
-        self.uri_schemes = ['dummy']
+        self.uri_schemes = ["dummy"]
 
 
 class DummyLibraryProvider(backend.LibraryProvider):
-    root_directory = Ref.directory(uri='dummy:/', name='dummy')
+    root_directory = Ref.directory(uri="dummy:/", name="dummy")
 
     def __init__(self, *args, **kwargs):
-        super(DummyLibraryProvider, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.dummy_library = []
         self.dummy_get_distinct_result = {}
         self.dummy_browse_result = {}
@@ -49,6 +47,7 @@ class DummyLibraryProvider(backend.LibraryProvider):
         return self.dummy_get_distinct_result.get(field, set())
 
     def lookup(self, uri):
+        uri = Ref.track(uri=uri).uri
         return [t for t in self.dummy_library if uri == t.uri]
 
     def refresh(self, uri=None):
@@ -61,9 +60,8 @@ class DummyLibraryProvider(backend.LibraryProvider):
 
 
 class DummyPlaybackProvider(backend.PlaybackProvider):
-
     def __init__(self, *args, **kwargs):
-        super(DummyPlaybackProvider, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._uri = None
         self._time_position = 0
 
@@ -71,7 +69,7 @@ class DummyPlaybackProvider(backend.PlaybackProvider):
         return True
 
     def play(self):
-        return self._uri and self._uri != 'dummy:error'
+        return self._uri and self._uri != "dummy:error"
 
     def change_track(self, track):
         """Pass a track with URI 'dummy:error' to force failure"""
@@ -98,9 +96,8 @@ class DummyPlaybackProvider(backend.PlaybackProvider):
 
 
 class DummyPlaylistsProvider(backend.PlaylistsProvider):
-
     def __init__(self, backend):
-        super(DummyPlaylistsProvider, self).__init__(backend)
+        super().__init__(backend)
         self._playlists = []
         self._allow_save = True
 
@@ -113,16 +110,17 @@ class DummyPlaylistsProvider(backend.PlaylistsProvider):
 
     def as_list(self):
         return [
-            Ref.playlist(uri=pl.uri, name=pl.name) for pl in self._playlists]
+            Ref.playlist(uri=pl.uri, name=pl.name) for pl in self._playlists
+        ]
 
     def get_items(self, uri):
         playlist = self.lookup(uri)
         if playlist is None:
             return
-        return [
-            Ref.track(uri=t.uri, name=t.name) for t in playlist.tracks]
+        return [Ref.track(uri=t.uri, name=t.name) for t in playlist.tracks]
 
     def lookup(self, uri):
+        uri = Ref.playlist(uri=uri).uri
         for playlist in self._playlists:
             if playlist.uri == uri:
                 return playlist
@@ -131,7 +129,7 @@ class DummyPlaylistsProvider(backend.PlaylistsProvider):
         pass
 
     def create(self, name):
-        playlist = Playlist(name=name, uri='dummy:%s' % name)
+        playlist = Playlist(name=name, uri=f"dummy:{name}")
         self._playlists.append(playlist)
         return playlist
 
