@@ -1,18 +1,13 @@
-from __future__ import absolute_import, unicode_literals
-
-import mock
+from unittest import mock
 
 import pytest
-
 import requests
-
 import responses
 
 from mopidy.internal import http
 
-
 TIMEOUT = 1000
-URI = 'http://example.com/foo.txt'
+URI = "http://example.com/foo.txt"
 BODY = "This is the contents of foo.txt."
 
 
@@ -33,7 +28,7 @@ def test_download_on_server_side_error(session, caplog):
     result = http.download(session, URI)
 
     assert result is None
-    assert 'Problem downloading' in caplog.text
+    assert "Problem downloading" in caplog.text
 
 
 def test_download_times_out_if_connection_times_out(session_mock, caplog):
@@ -44,20 +39,22 @@ def test_download_times_out_if_connection_times_out(session_mock, caplog):
     session_mock.get.assert_called_once_with(URI, timeout=1.0, stream=True)
     assert result is None
     assert (
-        'Download of %r failed due to connection timeout after 1.000s' % URI
-        in caplog.text)
+        f"Download of {URI!r} failed due to connection timeout after 1.000s"
+        in caplog.text
+    )
 
 
 @responses.activate
 def test_download_times_out_if_download_is_slow(session, caplog):
-    responses.add(responses.GET, URI, body=BODY, content_type='text/plain')
+    responses.add(responses.GET, URI, body=BODY, content_type="text/plain")
 
-    with mock.patch.object(http, 'time') as time_mock:
+    with mock.patch.object(http, "time") as time_mock:
         time_mock.time.side_effect = [0, TIMEOUT + 1]
 
         result = http.download(session, URI)
 
     assert result is None
     assert (
-        'Download of %r failed due to download taking more than 1.000s' % URI
-        in caplog.text)
+        f"Download of {URI!r} failed due to download taking more than 1.000s"
+        in caplog.text
+    )
